ScreenInfo class

Contains information about the device screen dimensions and pixel density.

Used internally by the SDK to collect screen size data for analytics.

Constructors

ScreenInfo({required double width, required double height, required double devicePixelRatio})
Creates a new ScreenInfo instance.
const

Properties

devicePixelRatio double
The device pixel ratio (physical pixels per logical pixel).
final
hashCode int
The hash code for this object.
no setterinherited
height double
The screen height in logical pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
The screen width in logical pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the screen info to a JSON representation.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited